@@ -8,13 +8,13 @@ from pyeda.boolalg import boolfunc
 from pyeda.boolalg.expr import (
     exprvar,
     Expression,
-    Not, Or, And, Xor, Xnor, Equal, Unequal, Implies, ITE,
-    Nor, Nand, OneHot0, OneHot, Majority,
+    Not, Or, And, Nor, Nand, Xor, Xnor, Equal, Unequal, Implies, ITE,
+    OneHot0, OneHot, Majority, AchillesHeel,
     EXPRZERO, EXPRONE,
 )
 from pyeda.boolalg.vexpr import bitvec
 
-import nose
+from nose.tools import assert_raises
 
 a, b, c, d, e, p, q, s = map(exprvar, 'abcdepqs')
 
@@ -68,20 +68,46 @@ def test_box():
     assert Expression.box(1) is EXPRONE
     assert Expression.box('1') is EXPRONE
     assert Expression.box(a) is a
-    nose.tools.assert_raises(TypeError, Expression.box, 42)
+    assert Expression.box(42) is EXPRONE
 
 def test_nor():
+    assert Nor() is EXPRONE
+    assert Nor(a) is -a
+
     assert Nor(0, 0) is EXPRONE
     assert Nor(0, 1) is EXPRZERO
     assert Nor(1, 0) is EXPRZERO
     assert Nor(1, 1) is EXPRZERO
+
+    assert Nor(0, 0, 0) is EXPRONE
+    assert Nor(0, 0, 1) is EXPRZERO
+    assert Nor(0, 1, 0) is EXPRZERO
+    assert Nor(0, 1, 1) is EXPRZERO
+    assert Nor(1, 0, 0) is EXPRZERO
+    assert Nor(1, 0, 1) is EXPRZERO
+    assert Nor(1, 1, 0) is EXPRZERO
+    assert Nor(1, 1, 1) is EXPRZERO
+
     assert Nor(a, b).equivalent(-a * -b)
 
 def test_nand():
+    assert Nand() is EXPRZERO
+    assert Nand(a) is -a
+
     assert Nand(0, 0) is EXPRONE
     assert Nand(0, 1) is EXPRONE
     assert Nand(1, 0) is EXPRONE
     assert Nand(1, 1) is EXPRZERO
+
+    assert Nand(0, 0, 0) is EXPRONE
+    assert Nand(0, 0, 1) is EXPRONE
+    assert Nand(0, 1, 0) is EXPRONE
+    assert Nand(0, 1, 1) is EXPRONE
+    assert Nand(1, 0, 0) is EXPRONE
+    assert Nand(1, 0, 1) is EXPRONE
+    assert Nand(1, 1, 0) is EXPRONE
+    assert Nand(1, 1, 1) is EXPRZERO
+
     assert Nand(a, b).equivalent(-a + -b)
 
 def test_onehot0():
@@ -117,6 +143,11 @@ def test_majority():
     assert Majority(1, 1, 1) is EXPRONE
     assert Majority(a, b, c).equivalent(a * b + a * c + b * c)
 
+def test_achilles_heel():
+    assert AchillesHeel(a, b).equivalent(a + b)
+    assert AchillesHeel(a, b, c, d).equivalent((a + b) * (c + d))
+    assert_raises(ValueError, AchillesHeel, a, b, c)
+
 def test_ops():
     # __sub__, __rsub__
     assert (a - 0) is EXPRONE
@@ -702,3 +733,4 @@ def test_complete_sum():
     f = -v*x*y*z + -v*-w*x + -v*-x*-z + -v*w*x*z + -w*y*-z + v*-w*z + v*w*-x*z
     cs = -v*-w*x + v*-w*y + -v*-w*-z + v*-w*z + -v*-x*-z + -v*x*z + v*-x*z + -w*x*y + -w*x*z + -w*y*-z
     assert str(f.complete_sum()) == str(cs)
+
